@@ -1,5 +1,5 @@
 import os
-from typing import Optional, NamedTuple, List, Tuple
+from typing import List, NamedTuple, Optional, Tuple
 
 import xlrd
 
@@ -12,8 +12,8 @@ from strictdoc.backend.sdoc.models.document_grammar import (
 from strictdoc.backend.sdoc.models.object_factory import SDocObjectFactory
 from strictdoc.backend.sdoc.models.reference import ParentReqReference
 from strictdoc.backend.sdoc.models.requirement import (
-    RequirementField,
     Requirement,
+    RequirementField,
 )
 from strictdoc.backend.sdoc.models.type_system import GrammarElementFieldString
 
@@ -92,13 +92,6 @@ class ExcelToSDocConverter:
             all_header_columns.remove(header_column_idx)
         assert statement_column is not None
 
-        # array of tuples: (column_idx: int, column_name: str)
-        # [
-        #  (0, 'APPLICABLE_COMPONENT_CATEGORIES'),
-        #  (2, 'CATEGORY'),
-        #  ...
-        #  (6, 'CRITICALITY')
-        # ]
         extra_header_pairs: List[Tuple[int, str]] = list(
             map(lambda x: (x, safe_header_row[x]), all_header_columns)
         )
