@@ -1,8 +1,35 @@
+TEXT_TYPES_GRAMMAR = r"""
+TextPart[noskipws]:
+  (InlineLink | NormalString)
+;
+
+NormalString[noskipws]:
+  (!SpecialKeyword !FreeTextEnd /(?ms)./)*
+;
+
+SpecialKeyword:
+  InlineLinkStart // more keywords are coming later
+;
+
+InlineLinkStart: '[LINK: ';
+
+InlineLink[noskipws]:
+  InlineLinkStart value = /[^\]]*/ ']'
+;
+
+FreeTextEnd: /^/ '[/FREETEXT]' '\n';
+"""
+
+FREE_TEXT_PARSER_GRAMMAR = r"""
+FreeTextContainer[noskipws]:
+  parts+=TextPart
+;
+"""
+
 DOCUMENT_GRAMMAR = r"""
 Document[noskipws]:
   '[DOCUMENT]' '\n'
-  // NAME: is deprecated. Both documents and sections now have TITLE:.
-  (('NAME: ' name = /.*$/ '\n') | ('TITLE: ' title = /.*$/ '\n')?)
+  'TITLE: ' title = /.*$/ '\n'
   (config = DocumentConfig)?
   ('\n' grammar = DocumentGrammar)?
   free_texts *= SpaceThenFreeText
@@ -29,7 +56,8 @@ GrammarElementField[noskipws]:
   GrammarElementFieldString |
   GrammarElementFieldSingleChoice |
   GrammarElementFieldMultipleChoice |
-  GrammarElementFieldTag
+  GrammarElementFieldTag |
+  GrammarElementFieldReference
 ;
 
 GrammarElementFieldString[noskipws]:
@@ -58,6 +86,21 @@ GrammarElementFieldTag[noskipws]:
   '    REQUIRED: ' (required = BooleanChoice) '\n'
 ;
 
+GrammarElementFieldReference[noskipws]:
+  '  - TITLE: ' title=FieldName '\n'
+  '    TYPE: Reference'
+    '(' ((types = ReferenceType) (types *= ReferenceTypeXs)) ')' '\n'
+  '    REQUIRED: ' (required = BooleanChoice) '\n'
+;
+
+ReferenceType[noskipws]:
+  ('ParentReqReference' | 'FileReference' | 'BibReference')
+;
+
+ReferenceTypeXs[noskipws]:
+  /, /- ReferenceType
+;
+
 BooleanChoice[noskipws]:
   ('True' | 'False')
 ;
@@ -65,6 +108,7 @@ BooleanChoice[noskipws]:
 DocumentConfig[noskipws]:
   ('UID: ' uid = /.*$/ '\n')?
   ('VERSION: ' version = /.*$/ '\n')?
+  ('CLASSIFICATION: ' classification = /.*$/ '\n')?
 
   ('OPTIONS:' '\n'
     ('  MARKUP: ' (markup = MarkupChoice) '\n')?
@@ -81,7 +125,7 @@ MarkupChoice[noskipws]:
 ;
 
 RequirementStyleChoice[noskipws]:
-  'Inline' | 'Table'
+  'Inline' | 'Simple' | 'Table' | 'Zebra'
 ;
 
 RequirementHasTitleChoice[noskipws]:
@@ -106,7 +150,7 @@ Section[noskipws]:
   '[SECTION]'
   '\n'
   ('UID: ' uid = /.+$/ '\n')?
-  ('LEVEL: ' level = /.*/ '\n')?
+  ('LEVEL: ' custom_level = /.*/ '\n')?
   'TITLE: ' title = /.*$/ '\n'
   free_texts *= SpaceThenFreeText
   section_contents *= SectionOrRequirement
@@ -185,39 +229,13 @@ ChoiceOptionXs[noskipws]:
 RequirementStatus[noskipws]:
   'Draft' | 'Active' | 'Deleted';
 
-RequirementComment[noskipws]:
-  'COMMENT: ' (
-    comment_single = SingleLineString | comment_multiline = MultiLineString
-  ) '\n'
-;
-
 FreeText[noskipws]:
   '[FREETEXT]' '\n'
   parts+=TextPart
   FreeTextEnd
 ;
-
-FreeTextEnd: /^/ '[/FREETEXT]' '\n';
-
-TextPart[noskipws]:
-  (InlineLink | NormalString)
-;
-
-NormalString[noskipws]:
-  (!SpecialKeyword !FreeTextEnd /(?ms)./)*
-;
-
-SpecialKeyword:
-  InlineLinkStart // more keywords are coming later
-;
-
-InlineLinkStart: '[LINK: ';
-
-InlineLink[noskipws]:
-  InlineLinkStart value = /[^\]]*/ ']'
-;
-
 """
 
-STRICTINC_GRAMMAR = FRAGMENT_GRAMMAR + SECTION_GRAMMAR
-STRICTDOC_GRAMMAR = DOCUMENT_GRAMMAR + SECTION_GRAMMAR
+STRICTINC_GRAMMAR = FRAGMENT_GRAMMAR + SECTION_GRAMMAR + TEXT_TYPES_GRAMMAR
+STRICTDOC_GRAMMAR = DOCUMENT_GRAMMAR + SECTION_GRAMMAR + TEXT_TYPES_GRAMMAR
+FREE_TEXT_GRAMMAR = FREE_TEXT_PARSER_GRAMMAR + TEXT_TYPES_GRAMMAR
