@@ -1,4 +1,5 @@
 from strictdoc.backend.sdoc.grammar.grammar import (
+    FREE_TEXT_GRAMMAR,
     STRICTDOC_GRAMMAR,
     STRICTINC_GRAMMAR,
 )
@@ -20,6 +21,10 @@ class SDocGrammarBuilder:
         )
         return grammar
 
+    @staticmethod
+    def create_free_text_grammar():
+        return SDocGrammarBuilder._prep_grammar(FREE_TEXT_GRAMMAR)
+
     @staticmethod
     def create_fragment_grammar():
         grammar = SDocGrammarBuilder._prep_grammar(
