@@ -23,17 +23,41 @@ MultiLineString[noskipws]:
 
 Reference[noskipws]:
   // FileReference is an early, experimental feature. Do not use yet.
-  ParentReqReference | FileReference
+  ParentReqReference | FileReference | BibReference
 ;
 
 ParentReqReference[noskipws]:
-  '- TYPE: ' ref_type = 'Parent' '\n'
-  '  VALUE: ' path = /.*$/ '\n'
+  '- TYPE: Parent' '\n'
+  '  VALUE: ' ref_uid = /.*$/ '\n'
 ;
 
 FileReference[noskipws]:
   // FileReference is an early, experimental feature. Do not use yet.
-  '- TYPE: ' ref_type = 'File' '\n'
-  '  VALUE: ' path = /.*$/ '\n'
+  '- TYPE: File' '\n'
+  g_file_entry = FileEntry
 ;
+
+FileEntry[noskipws]:
+  ('  FORMAT: ' g_file_format = FileEntryFormat '\n')?
+   '  VALUE: ' g_file_path = /.*$/ '\n'
+;
+
+FileEntryFormat[noskipws]:
+  'Sourcecode' | 'Python' | /[A-Z]+[A-Z_]*/
+;
+
+BibReference[noskipws]:
+  '- TYPE: BibRef' '\n'
+  bib_entry = BibEntry
+;
+
+BibEntry[noskipws]:
+  ('  FORMAT: ' bib_format = BibEntryFormat '\n')?
+   '  VALUE: ' bib_value = /.*$/ '\n'
+;
+
+BibEntryFormat[noskipws]:
+  'String' | 'BibTex' | 'Citation'
+;
+
 """
