@@ -1,9 +1,12 @@
 from typing import Optional
 
+from strictdoc.helpers.auto_described import auto_described
 
+
+@auto_described
 class DocumentConfig:  # pylint: disable=too-many-instance-attributes
     @staticmethod
-    def default_config(document):
+    def default_config(document) -> "DocumentConfig":
         return DocumentConfig(
             parent=document,
             version=None,
@@ -29,18 +32,33 @@ class DocumentConfig:  # pylint: disable=too-many-instance-attributes
     ):
         self.parent = parent
         self.version: Optional[str] = version
-        self.uid: Optional[str] = uid
+
+        meaningful_uid: Optional[str] = None
+        if uid is not None and len(uid) > 0:
+            meaningful_uid = uid
+        self.uid: Optional[str] = meaningful_uid
+
         self.classification: Optional[str] = classification
         self.markup = markup
         self.auto_levels: bool = auto_levels is None or auto_levels == "On"
+        # Possible requirement styles:
+        # Simple, Table, Rows
         self.requirement_style: Optional[str] = requirement_style
         self.requirement_in_toc: Optional[str] = requirement_in_toc
         self.ng_auto_levels_specified = auto_levels is not None
 
-    def is_inline_requirements(self):
-        return (
-            self.requirement_style is None or self.requirement_style == "Inline"
-        )
+    def get_requirement_style_mode(self):
+        if (
+            self.requirement_style is None
+            or self.requirement_style == "Inline"
+            or self.requirement_style == "Simple"
+        ):
+            return "simple"
+        if self.requirement_style == "Table":
+            return "table"
+        if self.requirement_style == "Zebra":
+            return "zebra"
+        raise NotImplementedError(self.requirement_style)
 
     def is_requirement_in_toc(self):
         return (
@@ -51,19 +69,10 @@ class DocumentConfig:  # pylint: disable=too-many-instance-attributes
         # TODO: When OPTIONS are not provided to a document, the self.number and
         # self.version are both None. Otherwise, they become empty strings "".
         # This issue might deserve a bug report to TextX.
-        return (self.uid is not None and len(self.uid) > 0) or (
-            self.version is not None and len(self.version) > 0
-        )
-
-    def __str__(self):
         return (
-            f"{self.__class__.__name__}("
-            f"version: {self.version}, "
-            f"uid: {self.uid}, "
-            f"classification: {self.classification}, "
-            f"markup: {self.markup}, "
-            f"auto_levels: {self.auto_levels}, "
-            f"requirement_style: {self.requirement_style}, "
-            f"requirement_in_toc: {self.requirement_in_toc}, "
-            ")"
+            (self.uid is not None and len(self.uid) > 0)
+            or (self.version is not None and len(self.version) > 0)
+            or (
+                self.classification is not None and len(self.classification) > 0
+            )
         )
