@@ -8,7 +8,7 @@ from strictdoc.backend.sdoc.grammar.grammar_builder import SDocGrammarBuilder
 from strictdoc.backend.sdoc.include_reader import SDIncludeReader
 from strictdoc.backend.sdoc.models.constants import DOCUMENT_MODELS
 from strictdoc.backend.sdoc.models.fragment import Fragment
-from strictdoc.backend.sdoc.processor import SDocParsingProcessor, ParseContext
+from strictdoc.backend.sdoc.processor import ParseContext, SDocParsingProcessor
 from strictdoc.helpers.textx import drop_textx_meta
 
 
@@ -44,7 +44,7 @@ class SDReader:
         return document
 
     def read_from_file(self, file_path):
-        with open(file_path, "r", encoding="utf8") as file:
+        with open(file_path, encoding="utf8") as file:
             sdoc_content = file.read()
 
         try:
@@ -54,10 +54,10 @@ class SDReader:
             traceback.print_exc()
             sys.exit(1)
         except StrictDocSemanticError as exc:
-            print(exc.to_print_message())
+            print(exc.to_print_message())  # noqa: T201
             sys.exit(1)
         except Exception as exc:  # pylint: disable=broad-except
-            print(
+            print(  # noqa: T201
                 f"error: could not parse file: "
                 f"{file_path}.\n{exc.__class__.__name__}: {exc}"
             )
