@@ -33,7 +33,7 @@ def get_venv_command(venv_path: str, reset_path=True):
         else rf"{venv_path}\Scripts\activate"
     )
     venv_command = f"""
-        python3 -m venv {venv_path} && 
+        python3 -m venv {venv_path} &&
             {venv_command_activate}
     """
     if reset_path:
@@ -74,12 +74,16 @@ def run_invoke_cmd(
     venv_path = os.path.join(os.getcwd(), f".venv-{postfix}")
 
     with context.prefix(get_venv_command(venv_path, reset_path=reset_path)):
+        # FIXME: pip3 uninstall strictdoc -y" is here because I don't know how
+        # to make pip install only the dependencies from the pyproject.toml but
+        # not the project itself.
         if VENV_DEPS_CHECK_PASSED not in context:
             result = context.run(
                 one_line_command(
                     """
-                    pip install toml &&
-                    python3 check_environment.py
+                    pip3 install toml &&
+                    python3 check_environment.py &&
+                    pip3 uninstall strictdoc -y
                     """
                 ),
                 env=None,
@@ -117,7 +121,7 @@ def run_invoke_cmd(
 def clean(context):
     # https://unix.stackexchange.com/a/689930/77389
     clean_command = """
-        rm -rfv output/ docs/sphinx/build/    
+        rm -rfv output/ docs/sphinx/build/
     """
     run_invoke_cmd(context, clean_command)
 
@@ -126,7 +130,7 @@ def clean(context):
 def clean_itest_artifacts(context):
     # https://unix.stackexchange.com/a/689930/77389
     find_command = """
-        git clean -dfX tests/integration/    
+        git clean -dfX tests/integration/
     """
     # The command sometimes exits with 1 even if the files are deleted.
     # warn=True ensures that the execution continues.
@@ -134,7 +138,7 @@ def clean_itest_artifacts(context):
 
 
 @task
-def server(context, input_path="developer/sandbox"):
+def server(context, input_path="."):
     assert os.path.isdir(input_path), input_path
     run_invoke_cmd(
         context,
@@ -147,7 +151,7 @@ def server(context, input_path="developer/sandbox"):
 
 
 @task
-def sphinx(context):
+def docs(context):
     run_invoke_cmd(
         context,
         (
@@ -155,12 +159,27 @@ def sphinx(context):
             python3 strictdoc/cli/main.py
                 export docs/
                     --formats=html
-                    --output-dir output/sphinx
+                    --output-dir output/strictdoc_website
                     --project-title "StrictDoc"
             """
         ),
     )
 
+    assert os.path.isdir(
+        "strictdoc-project.github.io/"
+    ), "Expecting the documentation to be cloned."
+    assert os.path.isdir(
+        "strictdoc-project.github.io/.git/"
+    ), "Expecting the documentation to be a valid Git repository."
+    run_invoke_cmd(
+        context,
+        (
+            """
+            cp -rv output/strictdoc_website/html/* strictdoc-project.github.io/
+            """
+        ),
+    )
+
     run_invoke_cmd(
         context,
         (
@@ -178,9 +197,7 @@ def sphinx(context):
         context,
         (
             """
-            cp -v output/sphinx/rst/strictdoc*.rst docs/sphinx/source/ &&
-            mkdir -p docs/strictdoc-html/strictdoc-html &&
-            cp -rv output/sphinx/html/* docs/strictdoc-html/strictdoc-html
+            cp -v output/sphinx/rst/strictdoc*.rst docs/sphinx/source/
             """
         ),
     )
@@ -225,18 +242,39 @@ def test_unit_server(context, focus=None):
 
 
 @task
-def test_end2end(context, focus=None, long_timeouts=False):
+def test_end2end(
+    context,
+    focus=None,
+    exit_first=False,
+    parallelize=False,
+    long_timeouts=False,
+):
+    if parallelize:
+        print(  # noqa: T201
+            "warning: "
+            "Running parallelized end-2-end tests is supported "
+            "but is not stable."
+        )
     focus_argument = f"-k {focus}" if focus is not None else ""
-    timeouts_argument = "STRICTDOC_LONGER_TIMEOUTS=1" if long_timeouts else ""
+    exit_first_argument = "--exitfirst" if exit_first else ""
+    parallelize_argument_1 = "STRICTDOC_PARALLELIZE=True" if parallelize else ""
+    parallelize_argument_2 = "--numprocesses=2" if parallelize else ""
+    timeouts_argument = (
+        "STRICTDOC_LONGER_TIMEOUTS=True" if long_timeouts else ""
+    )
     run_invoke_cmd(
         context,
         one_line_command(
             f"""
+            {parallelize_argument_1}
             {timeouts_argument}
             pytest
-                --exitfirst
+                --failed-first
                 --capture=no
+                --reuse-session
+                {parallelize_argument_2}
                 {focus_argument}
+                {exit_first_argument}
                 tests/end2end
             """
         ),
@@ -309,13 +347,15 @@ def test_integration(context, focus=None, debug=False, strictdoc=None):
 @task
 def lint_black_diff(context):
     command = """
-        black . --color --line-length 80 2>&1
+        black
+            *.py strictdoc/ tests/unit/ tests/integration/*.py tests/end2end/
+            --color --line-length 80 2>&1
         """
     result = run_invoke_cmd(context, command)
 
     # black always exits with 0, so we handle the output.
     if "reformatted" in result.stdout:
-        print("invoke: black found issues")
+        print("invoke: black found issues")  # noqa: T201
         result.exited = 1
         raise invoke.exceptions.UnexpectedExit(result)
 
@@ -332,7 +372,9 @@ def lint_pylint(context):
         run_invoke_cmd(context, command)
     except invoke.exceptions.UnexpectedExit as exc:
         # pylink doesn't show an error message when exit code != 0, so we do.
-        print(f"invoke: pylint exited with error code {exc.result.exited}")
+        print(  # noqa: T201
+            f"invoke: pylint exited with error code {exc.result.exited}"
+        )
         raise exc
 
 
@@ -344,6 +386,14 @@ def lint_flake8(context):
     run_invoke_cmd(context, command)
 
 
+@task
+def lint_ruff(context):
+    command = """
+        ruff .
+    """
+    run_invoke_cmd(context, command)
+
+
 @task
 def lint_mypy(context):
     # Need to delete the cache every time because otherwise mypy gets
@@ -351,7 +401,6 @@ def lint_mypy(context):
     run_invoke_cmd(
         context,
         """
-        rm -rfv .mypy_cache/ &&
         mypy strictdoc/
             --show-error-codes
             --disable-error-code=arg-type
@@ -374,6 +423,7 @@ def lint_mypy(context):
 @task
 def lint(context):
     lint_black_diff(context)
+    lint_ruff(context)
     lint_pylint(context)
     lint_flake8(context)
     lint_mypy(context)
@@ -436,7 +486,7 @@ def setup_development_deps(context):
 def release_local(context):
     context[VENV_FOLDER] = VenvFolderType.RELEASE_LOCAL
     command = """
-        rm -rfv dist/ build/ && 
+        rm -rfv dist/ build/ &&
         pip uninstall strictdoc -y &&
         python3 -m build &&
         twine check dist/* &&
@@ -463,16 +513,23 @@ def release(context, username=None, password=None):
 
 @task
 def release_test(context):
+    """
+    Release to test package index (TestPyPI)
+    https://test.pypi.org/project/strictdoc/0.0.34a1/
+    """
     context[VENV_FOLDER] = VenvFolderType.RELEASE_PYPI_TEST
     setup_development_deps(context)
 
+    # The token is in a core developer's .pypirc file.
+    # https://test.pypi.org/manage/account/token/
+    # https://packaging.python.org/en/latest/specifications/pypirc/#pypirc
     command = """
         rm -rfv dist/ &&
         python3 -m build &&
             twine check dist/* &&
             twine upload
-                --repository-url
-                    https://test.pypi.org/legacy/ dist/strictdoc-*.tar.gz
+                --repository strictdoc_test
+                dist/strictdoc-*.tar.gz
     """
     run_invoke_cmd(context, command)
 
@@ -492,6 +549,14 @@ def release_pyinstaller(context):
     # """
     # Solution found here:
     # https://stackoverflow.com/a/64473931/598057
+    #
+    # The --hidden-import strictdoc.server.app flag is needed because without
+    # it, the following is produced:
+    # ERROR: Error loading ASGI app. Could not import
+    # module "strictdoc.server.app".
+    # Solution found here: https://stackoverflow.com/a/71340437/598057
+    # This behavior is not surprising because that's how the uvicorn loads the
+    # application separately from the parent process.
     command = f"""
         pip install pyinstaller &&
         pyinstaller
@@ -500,6 +565,7 @@ def release_pyinstaller(context):
             --noconfirm
             --additional-hooks-dir developer/pyinstaller_hooks
             --distpath {path_to_pyi_dist}
+            --hidden-import strictdoc.server.app
             --add-data strictdoc/export/html/templates:templates/html
             --add-data strictdoc/export/rst/templates:templates/rst
             --add-data strictdoc/export/html/_static:_static
@@ -510,13 +576,13 @@ def release_pyinstaller(context):
 
 
 @task
-def watch(context, sdocs_path="developer/sandbox"):
+def watch(context, sdocs_path="."):
     paths_to_watch = "."
     strictdoc_command = f"""
         python strictdoc/cli/main.py
             export
             {sdocs_path}
-            --output-dir {sdocs_path}/output
+            --output-dir output/
             --experimental-enable-file-traceability
     """
     run_invoke_cmd(
@@ -524,7 +590,7 @@ def watch(context, sdocs_path="developer/sandbox"):
         f"""
         {strictdoc_command} &&
         watchmedo shell-command
-        --patterns="*.py;*.sdoc;*.html;*.css;*.js"
+        --patterns="*.py;*.sdoc;*.jinja;*.html;*.css;*.js"
         --recursive
         --ignore-pattern='output/;tests/integration'
         --command='{strictdoc_command}'
@@ -542,3 +608,28 @@ def run(context, command):
         {command}
         """,
     )
+
+
+@task
+def nuitka(context):
+    run_invoke_cmd(
+        context,
+        f"""
+        PYTHONPATH="{os.getcwd()}"
+        python -m nuitka
+            --static-libpython=no
+            --standalone
+            --include-module=textx
+            --include-module=pybtex.database.input.bibtex
+            --include-module=strictdoc.server.app
+            --include-module=docutils
+            --include-module=docutils.readers.standalone
+            --include-module=docutils.parsers.rst
+            --include-data-dir=strictdoc/export/html/templates=templates/html
+            --include-data-dir=strictdoc/export/rst/templates=templates/rst
+            --include-data-dir=strictdoc/export/html/_static=_static
+            --include-data-dir=strictdoc/export/html/_static_extra/mathjax=_static_extra/mathjax
+            --include-package-data=docutils
+            strictdoc/cli/main.py
+        """,
+    )
