@@ -22,32 +22,32 @@ def test_01():
     section1 = sdoc.section_contents[0]
     assert section1.title == "Section 1"
     section1_reqs = section1.section_contents
-    assert section1_reqs[0].uid == "REQ-1-1 UID"
-    assert section1_reqs[0].title == "REQ-1-1 Title"
-    assert section1_reqs[0].statement_multiline == "REQ-1-1 Statement"
-    assert section1_reqs[0].rationale_multiline == "REQ-1-1 Rationale"
+    assert section1_reqs[0].reserved_uid == "REQ-1-1 UID"
+    assert section1_reqs[0].reserved_title == "REQ-1-1 Title"
+    assert section1_reqs[0].reserved_statement == "REQ-1-1 Statement"
+    assert section1_reqs[0].rationale == "REQ-1-1 Rationale"
     assert len(section1_reqs[0].comments) == 0
 
-    assert section1_reqs[1].uid == "REQ-1-2 UID"
-    assert section1_reqs[1].title == "REQ-1-2 Title"
-    assert section1_reqs[1].statement_multiline == "REQ-1-2 Statement"
-    assert section1_reqs[1].rationale_multiline == "REQ-1-2 Rationale"
-    assert section1_reqs[1].comments[0].comment_multiline == "REQ-1-2 Comment"
+    assert section1_reqs[1].reserved_uid == "REQ-1-2 UID"
+    assert section1_reqs[1].reserved_title == "REQ-1-2 Title"
+    assert section1_reqs[1].reserved_statement == "REQ-1-2 Statement"
+    assert section1_reqs[1].rationale == "REQ-1-2 Rationale"
+    assert section1_reqs[1].comments[0] == "REQ-1-2 Comment"
 
     section2 = sdoc.section_contents[1]
     assert section2.title == "Section 2"
     section2_reqs = section2.section_contents
-    assert section2_reqs[0].uid == "REQ-2-1 UID"
-    assert section2_reqs[0].title == "REQ-2-1 Title"
-    assert section2_reqs[0].statement_multiline == "REQ-2-1 Statement"
-    assert section2_reqs[0].rationale_multiline == "REQ-2-1 Rationale"
+    assert section2_reqs[0].reserved_uid == "REQ-2-1 UID"
+    assert section2_reqs[0].reserved_title == "REQ-2-1 Title"
+    assert section2_reqs[0].reserved_statement == "REQ-2-1 Statement"
+    assert section2_reqs[0].rationale == "REQ-2-1 Rationale"
     assert len(section2_reqs[0].comments) == 0
 
-    assert section2_reqs[1].uid == "REQ-2-2 UID"
-    assert section2_reqs[1].title == "REQ-2-2 Title"
-    assert section2_reqs[1].statement_multiline == "REQ-2-2 Statement"
-    assert section2_reqs[1].rationale_multiline == "REQ-2-2 Rationale"
-    assert section2_reqs[1].comments[0].comment_multiline == "REQ-2-2 Comment"
+    assert section2_reqs[1].reserved_uid == "REQ-2-2 UID"
+    assert section2_reqs[1].reserved_title == "REQ-2-2 Title"
+    assert section2_reqs[1].reserved_statement == "REQ-2-2 Statement"
+    assert section2_reqs[1].rationale == "REQ-2-2 Rationale"
+    assert section2_reqs[1].comments[0] == "REQ-2-2 Comment"
 
 
 def test_02():
@@ -65,18 +65,13 @@ def test_02():
     section1 = sdoc.section_contents[0]
     assert section1.title == "Section 1"
     section1_reqs = section1.section_contents
-    assert section1_reqs[0].uid == "REQ-1-1 UID"
-    assert section1_reqs[0].title == "REQ-1-1 Title"
-    assert section1_reqs[0].statement_multiline == "REQ-1-1 Statement"
-    assert section1_reqs[0].rationale_multiline == "REQ-1-1 Rationale"
+    assert section1_reqs[0].reserved_uid == "REQ-1-1 UID"
+    assert section1_reqs[0].reserved_title == "REQ-1-1 Title"
+    assert section1_reqs[0].reserved_statement == "REQ-1-1 Statement"
+    assert section1_reqs[0].rationale == "REQ-1-1 Rationale"
     assert len(section1_reqs[0].comments) == 1
-    assert (
-        section1_reqs[0].comments[0].comment_multiline
-        == "REQ-1-1 comment wrapped in p"
-    )
-    assert (
-        section1_reqs[1].comments[0].comment_multiline == "- Item 1\n- Item 2"
-    )
+    assert section1_reqs[0].comments[0] == "REQ-1-1 comment wrapped in p"
+    assert section1_reqs[1].comments[0] == "- Item 1\n- Item 2"
 
 
 def test_fragments_01():
