@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Link Health checker
 
@@ -29,14 +28,14 @@ import multiprocessing
 import os
 import re
 import sys
-import yaml
 from enum import Enum
 from queue import Empty
-from typing import Union, List
+from typing import List, Union
 
 import requests
+import yaml
 
-__version__ = "0.0.6"
+__version__ = "0.0.8"
 
 
 class Parallelizer:
@@ -85,7 +84,7 @@ class Parallelizer:
                 size -= 1
             except Empty:
                 if any(process.exitcode for process in self.processes):
-                    print(
+                    print(  # noqa: T201
                         "error: Parallelizer: One of the child processes "
                         "has exited prematurely."
                     )
@@ -134,6 +133,7 @@ class Status(str, Enum):
     HTTP_4xx = "HTTP_4xx"
     HTTP_403 = "HTTP_403"
     HTTP_5xx = "HTTP_5xx"
+    HTTP_999 = "HTTP_999"
     CONNECTION_ERROR = "CONNECTION_ERROR"
     SSL_ERROR = "SSL_ERROR"
     CONNECT_TIMEOUT = "CONNECT_TIMEOUT"
@@ -171,6 +171,8 @@ class ResponseData:
             return ResponseData(link, Status.HTTP_4xx, None)
         if 500 <= response.status_code < 600:
             return ResponseData(link, Status.HTTP_5xx, None)
+        if response.status_code == 999:
+            return ResponseData(link, Status.HTTP_999, None)
         else:
             raise NotImplementedError(response)
 
@@ -207,12 +209,14 @@ class ResponseData:
         return self.status == Status.SSL_ERROR
 
     def get_error_message(self):
-        payload_string = str(self.payload) if self.payload is not None else ""
-        return " ".join([str(self.status), payload_string])
+        if self.payload is not None:
+            return f"{self.status.value} {str(self.payload)}"
+        return str(self.status.value)
 
     def get_error_message_with_link(self):
-        payload_string = str(self.payload) if self.payload is not None else ""
-        return " ".join([str(self.status), payload_string, self.link])
+        if self.payload is not None:
+            return f"{self.status.value} {self.payload} {str(self.link)}"
+        return f"{self.status.value} {str(self.link)}"
 
     def promote_to_expected(self):
         self.expected = True
@@ -248,29 +252,33 @@ def check_link(link_and_exceptions) -> ResponseData:
     exceptions = link_and_exceptions[1]
 
     head_response = head_request(link)
-    print(".", end="")
+    print(".", end="")  # noqa: T201
     if head_response.is_success():
         return head_response
 
     if link in exceptions:
         code = exceptions[link]
         if head_response.status.value == code:
-            print(
+            print(  # noqa: T201
                 f"\nHEAD {link} -> Known exception: "
                 f"[{head_response.get_error_message()}]"
             )
             head_response.promote_to_expected()
             return head_response
 
-    print(f"\nHEAD {link} [{head_response.get_error_message()}]")
+    print(  # noqa: T201
+        f"\nHEAD {link} [{head_response.get_error_message()}]"
+    )
 
     get_response = get_request(link=link, verify=True)
     if get_response.is_success():
         return get_response
 
     if get_response.is_ssl_error():
-        print(f"\nGET {link} [{get_response.get_error_message()}]", end="\n")
-        print(
+        print(  # noqa: T201
+            f"\nGET {link} [{get_response.get_error_message()}]", end="\n"
+        )  # noqa: T201
+        print(  # noqa: T201
             f"\nGET {link} – Trying again without SSL verification...", end="\n"
         )
 
@@ -278,13 +286,29 @@ def check_link(link_and_exceptions) -> ResponseData:
         if get_response.is_success():
             return get_response
 
-    print(f"\nGET {link} [{get_response.get_error_message()}]", end="\n")
+    print(  # noqa: T201
+        f"\nGET {link} [{get_response.get_error_message()}]", end="\n"
+    )
 
     return get_response
 
 
 def find_links(input_content):
-    return re.findall(r"(?P<url>https?://[^\s><]+[^.\s><])", input_content)
+    # This regex is extremely simple, but it does the job for the links
+    # encountered and put under test so far.
+    PART_REGEX = r"[A-Za-z0-9_\-%+]+"
+    matches = re.findall(
+        (
+            rf"(?P<url>https?://({PART_REGEX}[\.\/])+{PART_REGEX}\/?"
+            rf"(\?({PART_REGEX}={PART_REGEX}&)*{PART_REGEX}={PART_REGEX})?"
+            ")"
+        ),
+        input_content,
+    )
+    links = []
+    for match in matches:
+        links.append(match[0])
+    return links
 
 
 def main():
@@ -296,18 +320,18 @@ def main():
     input_path = args.input_path
     assert os.path.exists(input_path)
 
-    with open(input_path, "r") as input_file:
+    with open(input_path) as input_file:
         input_content = input_file.read()
 
     exceptions = {}
 
     config_file_name = ".link_health.yml"
     if os.path.isfile(config_file_name):
-        with open(config_file_name, "r") as stream:
+        with open(config_file_name) as stream:
             try:
                 config_dict = yaml.safe_load(stream)
             except yaml.YAMLError as exc:
-                print(exc)
+                print(exc)  # noqa: T201
                 sys.exit(1)
         if "exceptions" in config_dict:
             exceptions_dict = config_dict["exceptions"]
@@ -337,15 +361,17 @@ def main():
         filter(lambda r: not r.is_success() and not r.expected, responses)
     )
 
-    print("\n")
+    print("\n")  # noqa: T201
     for expected_failed_response in expected_failed_responses:
-        print(
+        print(  # noqa: T201
             f"Expectedly failed link: "
             f"{expected_failed_response.get_error_message_with_link()}"
         )
     for failed_response in failed_responses:
-        print(f"Failed link: {failed_response.get_error_message_with_link()}")
-    print(
+        print(  # noqa: T201
+            f"Failed link: {failed_response.get_error_message_with_link()}"
+        )
+    print(  # noqa: T201
         f"Total links: {len(responses) - len(failed_responses)}, "
         f"failed links: {len(failed_responses)}"
     )
